<?xml version="1.0" encoding="UTF-8"?>
<!--
   Copyright 2010 Anyware Services

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
   -->
<xsl:stylesheet version="1.0" 
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
                xmlns:i18n="http://apache.org/cocoon/i18n/2.1"
                xmlns:xalan="http://xml.apache.org/xalan"
                exclude-result-prefixes="xalan">
	
    <xsl:import href="resource://org/ametys/runtime/kernel/stylesheets/ui.xsl"/>
    
    <xsl:param name="contextPath"/>
    <xsl:param name="workspaceName"/>
    <xsl:param name="workspaceURI"/>
    
    <xsl:variable name="debugMode">true</xsl:variable>
    
    <xsl:variable name="workspaceContext"><xsl:value-of select="$contextPath"/><xsl:value-of select="$workspaceURI"/></xsl:variable>

	<xsl:template match="/">
		<html>
			<!-- ****** HEAD ****** -->
			<head> 
				<meta http-equiv="X-UA-Compatible" content="IE=8" />
                <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
				<title>
					<i18n:text i18n:catalogue="workspace.{$workspaceName}" i18n:key="WORKSPACE_REPOSITORY_LABEL_SHORT"/>
				</title>  
				
                <link rel="icon" type="image/gif" href="{$contextPath}/kernel/resources/img/runtime_favico.gif" />
                <link rel="shortcut icon" type="image/x-icon" href="{$contextPath}/kernel/resources/img/runtime_favico.ico" />
                <link rel="stylesheet" href="{$contextPath}/kernel/resources/css/homepage/view.css" type="text/css"/>
                <link rel="stylesheet" href="{$contextPath}{$workspaceURI}/resources/css/home.css" type="text/css"/>
                <link rel="stylesheet" href="{$contextPath}{$workspaceURI}/resources/css/tooltip.css" type="text/css"/>
		        
		        <style type="text/css">
					#top { background-image: url('<xsl:value-of select="$workspaceContext"/>/resources/img/top.jpg'); } 
				</style>
		
				<!-- loading ui library -->
                <xsl:call-template name="ui-load">
                    <xsl:with-param name="pluginsDirectContext" select="concat($workspaceContext, '/plugins')"/>
                    <xsl:with-param name="pluginsWrappedContext" select="concat($workspaceContext, '/_plugins')"/>
                </xsl:call-template>
                <xsl:call-template name="ui-tools-load">
                    <xsl:with-param name="bad-navigator-redirection"><xsl:value-of select="$contextPath"/>/_admin/public/navigator.html</xsl:with-param>

                  	<xsl:with-param name="accept-ie-7">true</xsl:with-param>
					<xsl:with-param name="accept-ie-8">true</xsl:with-param>
					<xsl:with-param name="accept-ie-9">false</xsl:with-param>
					<xsl:with-param name="accept-ff-1.0">false</xsl:with-param>
					<xsl:with-param name="accept-ff-1.5">true</xsl:with-param>
					<xsl:with-param name="accept-ff-2.0">true</xsl:with-param>
					<xsl:with-param name="accept-ff-3.0">true</xsl:with-param>
					<xsl:with-param name="accept-ff-3.5">true</xsl:with-param>
					<xsl:with-param name="accept-ff-3.6">true</xsl:with-param>
					<xsl:with-param name="accept-ff-4.0">true</xsl:with-param>
					<xsl:with-param name="accept-ff-5.0">true</xsl:with-param>
					<xsl:with-param name="accept-ff-6.0">true</xsl:with-param>
					<xsl:with-param name="accept-ff-7.0">true</xsl:with-param>
					<xsl:with-param name="accept-ff-8.0">true</xsl:with-param>
					<xsl:with-param name="accept-ff-9.0">true</xsl:with-param>
					<xsl:with-param name="accept-ff-10.0">true</xsl:with-param>
					<xsl:with-param name="accept-sa-3">true</xsl:with-param>
					<xsl:with-param name="accept-sa-4">true</xsl:with-param>
					<xsl:with-param name="accept-sa-5.0">false</xsl:with-param>
					<xsl:with-param name="accept-op-9">false</xsl:with-param>
					<xsl:with-param name="accept-op-10">false</xsl:with-param>
					<xsl:with-param name="accept-op-11">false</xsl:with-param>
					<xsl:with-param name="accept-ch-1">false</xsl:with-param>
					<xsl:with-param name="accept-ch-2">false</xsl:with-param>
					<xsl:with-param name="accept-ch-3">false</xsl:with-param>
					<xsl:with-param name="accept-ch-4">false</xsl:with-param>
					<xsl:with-param name="accept-ch-5">false</xsl:with-param>
					<xsl:with-param name="accept-ch-6">false</xsl:with-param>
					<xsl:with-param name="accept-ch-7">false</xsl:with-param>
					<xsl:with-param name="accept-ch-8">false</xsl:with-param>
					<xsl:with-param name="accept-ch-9">false</xsl:with-param>
					<xsl:with-param name="accept-ch-10">false</xsl:with-param>
					<xsl:with-param name="accept-ch-11">false</xsl:with-param>
					<xsl:with-param name="accept-ch-12">false</xsl:with-param>
					<xsl:with-param name="accept-ch-13">false</xsl:with-param>
					<xsl:with-param name="accept-ch-14">false</xsl:with-param>
					<xsl:with-param name="debug-mode" select="$debugMode"/>
                </xsl:call-template>
                
                <link rel="stylesheet" type="text/css" href="{$contextPath}/plugins/extjs/resources/css/xtheme-gray.css" />
               
                <xsl:call-template name="workspace-head"/>
                
                <script type="text/javascript" src="{$contextPath}/kernel/resources/js/org/ametys/runtime/HomePage.js"><xsl:comment>//empty</xsl:comment></script>
               
               <script type="text/javascript">
                	<xsl:if test="/Workspace/Versions/Component|/Plugins/Versions/Component">
	                	
	                	var data = {versions : []};
	                	<xsl:for-each select="/Workspace/Versions/Component|/Plugins/Versions/Component">
	                		data.versions.push({
	                			name : "<xsl:value-of select="Name"/>",
	                			version: "<xsl:value-of select="Version"/>",
	                			date : "<xsl:if test="Date">&#160;du <xsl:value-of select="Date"/> à <xsl:value-of select="Time"/></xsl:if><xsl:if test="position() != last()">&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;</xsl:if>"
	                		});
	                	</xsl:for-each>
	                	org.ametys.runtime.HomePage._tplFooter = new Ext.XTemplate (
	                		'&lt;div id="versions"&gt;',
	                		'&lt;tpl for="versions"&gt;',
	                		'&lt;span class="title"&gt;{name}&#160;-&#160;&lt;/span&gt;',
	                		'{version}',
	                		'{date}',
	                		'&lt;/tpl&gt;',
	                		'&lt;/div&gt;'
	                	);
	                	
	                	org.ametys.runtime.HomePage._tplFooter.compile();
	                	
	              		org.ametys.runtime.HomePage.drawFooterPanel = function ()
						{
							return new org.ametys.HtmlContainer (
							{
			   					border: false,
			   					html : '',
			   					listeners: {
							        'render' : function(p) {
							        	org.ametys.runtime.HomePage._tplFooter.overwrite(p.getEl(), data);
							        }
			    				}
			
							});
						}
					</xsl:if>
                </script>
                
                <xsl:comment>[if lt IE 7]&gt;
						&lt;script defer="defer" type="text/javascript" src="<xsl:value-of select="$workspaceContext"/>/resources/js/pngfix.js">&lt;/script&gt;
				&lt;![endif]</xsl:comment>
				<xsl:call-template name="workspace-script"/>
			</head>
		
			<!-- ****** BODY ****** -->
			<body>
				<xsl:call-template name="workspace-body"/>
			</body>
		</html>		
	</xsl:template>
    
    <xsl:template name="workspace-head"/>
    <xsl:template name="workspace-title"/>
    <xsl:template name="workspace-body"/>
    <xsl:template name="workspace-script"/>
	
</xsl:stylesheet>
	